""" Object-oriented B-Spline and NURBS evaluation library in pure Python

.. moduleauthor:: Onur Rauf Bingol <orbingol@gmail.com>

"""

__author__ = "Onur Rauf Bingol"
__version__ = "4.2.1"
__license__ = "MIT"


import os
import sys
import abc
import math
from array import array
import random
import copy
import warnings
import struct
import pickle
import six
